# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ec2_subnet.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61ws/aws_ec2_subnet.proto\x12\x1aoak9.tython.aws.ec2_subnet\x1a\x13shared/shared.proto\"\xcc\x02\n\x06Subnet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\'\n\x1f\x61ssign_ipv6_address_on_creation\x18\x02 \x01(\x08\x12\x19\n\x11\x61vailability_zone\x18\x03 \x01(\t\x12\x12\n\ncidr_block\x18\x04 \x01(\t\x12\x17\n\x0fipv6_cidr_block\x18\x05 \x01(\t\x12\x1f\n\x17map_public_ip_on_launch\x18\x06 \x01(\x08\x12:\n\x04tags\x18\x07 \x03(\x0b\x32,.oak9.tython.aws.ec2_subnet.Subnet.TagsEntry\x12\x0e\n\x06vpc_id\x18\x08 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xca\x02\n\nEC2_Subnet\x12\x32\n\x06subnet\x18\x01 \x01(\x0b\x32\".oak9.tython.aws.ec2_subnet.Subnet\x12\x46\n\x11subnet_cidr_block\x18\x02 \x01(\x0b\x32+.oak9.tython.aws.ec2_subnet.SubnetCidrBlock\x12_\n\x1esubnet_network_acl_association\x18\x03 \x01(\x0b\x32\x37.oak9.tython.aws.ec2_subnet.SubnetNetworkAclAssociation\x12_\n\x1esubnet_route_table_association\x18\x04 \x01(\x0b\x32\x37.oak9.tython.aws.ec2_subnet.SubnetRouteTableAssociation\"v\n\x0fSubnetCidrBlock\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fipv6_cidr_block\x18\x02 \x01(\t\x12\x11\n\tsubnet_id\x18\x03 \x01(\t\"\x81\x01\n\x1bSubnetNetworkAclAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0enetwork_acl_id\x18\x02 \x01(\t\x12\x11\n\tsubnet_id\x18\x03 \x01(\t\"\x81\x01\n\x1bSubnetRouteTableAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eroute_table_id\x18\x02 \x01(\t\x12\x11\n\tsubnet_id\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ec2_subnet_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SUBNET_TAGSENTRY._options = None
  _SUBNET_TAGSENTRY._serialized_options = b'8\001'
  _SUBNET._serialized_start=78
  _SUBNET._serialized_end=410
  _SUBNET_TAGSENTRY._serialized_start=367
  _SUBNET_TAGSENTRY._serialized_end=410
  _EC2_SUBNET._serialized_start=413
  _EC2_SUBNET._serialized_end=743
  _SUBNETCIDRBLOCK._serialized_start=745
  _SUBNETCIDRBLOCK._serialized_end=863
  _SUBNETNETWORKACLASSOCIATION._serialized_start=866
  _SUBNETNETWORKACLASSOCIATION._serialized_end=995
  _SUBNETROUTETABLEASSOCIATION._serialized_start=998
  _SUBNETROUTETABLEASSOCIATION._serialized_end=1127
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeAutoscalerXAutoscalingPolicyXCpuUtilization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREDICTIVE_METHOD_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    predictive_method: builtins.str
    target: builtins.float
    def __init__(
        self,
        *,
        predictive_method: builtins.str = ...,
        target: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["predictive_method", b"predictive_method", "target", b"target"]) -> None: ...

global___ComputeAutoscalerXAutoscalingPolicyXCpuUtilization = ComputeAutoscalerXAutoscalingPolicyXCpuUtilization

@typing_extensions.final
class ComputeAutoscalerXAutoscalingPolicyXLoadBalancingUtilization(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_FIELD_NUMBER: builtins.int
    target: builtins.float
    def __init__(
        self,
        *,
        target: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target", b"target"]) -> None: ...

global___ComputeAutoscalerXAutoscalingPolicyXLoadBalancingUtilization = ComputeAutoscalerXAutoscalingPolicyXLoadBalancingUtilization

@typing_extensions.final
class ComputeAutoscalerXAutoscalingPolicyXMetric(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    target: builtins.float
    type: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        target: builtins.float = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "target", b"target", "type", b"type"]) -> None: ...

global___ComputeAutoscalerXAutoscalingPolicyXMetric = ComputeAutoscalerXAutoscalingPolicyXMetric

@typing_extensions.final
class ComputeAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIXED_FIELD_NUMBER: builtins.int
    PERCENT_FIELD_NUMBER: builtins.int
    fixed: builtins.float
    percent: builtins.float
    def __init__(
        self,
        *,
        fixed: builtins.float = ...,
        percent: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fixed", b"fixed", "percent", b"percent"]) -> None: ...

global___ComputeAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas = ComputeAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas

@typing_extensions.final
class ComputeAutoscalerXAutoscalingPolicyXScaleInControl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_WINDOW_SEC_FIELD_NUMBER: builtins.int
    MAX_SCALED_IN_REPLICAS_FIELD_NUMBER: builtins.int
    time_window_sec: builtins.float
    @property
    def max_scaled_in_replicas(self) -> global___ComputeAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas: ...
    def __init__(
        self,
        *,
        time_window_sec: builtins.float = ...,
        max_scaled_in_replicas: global___ComputeAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_scaled_in_replicas", b"max_scaled_in_replicas"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_scaled_in_replicas", b"max_scaled_in_replicas", "time_window_sec", b"time_window_sec"]) -> None: ...

global___ComputeAutoscalerXAutoscalingPolicyXScaleInControl = ComputeAutoscalerXAutoscalingPolicyXScaleInControl

@typing_extensions.final
class ComputeAutoscalerXAutoscalingPolicyXScalingSchedules(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    DURATION_SEC_FIELD_NUMBER: builtins.int
    MIN_REQUIRED_REPLICAS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    description: builtins.str
    disabled: builtins.bool
    duration_sec: builtins.float
    min_required_replicas: builtins.float
    name: builtins.str
    schedule: builtins.str
    time_zone: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        duration_sec: builtins.float = ...,
        min_required_replicas: builtins.float = ...,
        name: builtins.str = ...,
        schedule: builtins.str = ...,
        time_zone: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disabled", b"disabled", "duration_sec", b"duration_sec", "min_required_replicas", b"min_required_replicas", "name", b"name", "schedule", b"schedule", "time_zone", b"time_zone"]) -> None: ...

global___ComputeAutoscalerXAutoscalingPolicyXScalingSchedules = ComputeAutoscalerXAutoscalingPolicyXScalingSchedules

@typing_extensions.final
class ComputeAutoscalerXAutoscalingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COOLDOWN_PERIOD_FIELD_NUMBER: builtins.int
    MAX_REPLICAS_FIELD_NUMBER: builtins.int
    MIN_REPLICAS_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    CPU_UTILIZATION_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_UTILIZATION_FIELD_NUMBER: builtins.int
    METRIC_FIELD_NUMBER: builtins.int
    SCALE_IN_CONTROL_FIELD_NUMBER: builtins.int
    SCALING_SCHEDULES_FIELD_NUMBER: builtins.int
    cooldown_period: builtins.float
    max_replicas: builtins.float
    min_replicas: builtins.float
    mode: builtins.str
    @property
    def cpu_utilization(self) -> global___ComputeAutoscalerXAutoscalingPolicyXCpuUtilization: ...
    @property
    def load_balancing_utilization(self) -> global___ComputeAutoscalerXAutoscalingPolicyXLoadBalancingUtilization: ...
    @property
    def metric(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeAutoscalerXAutoscalingPolicyXMetric]: ...
    @property
    def scale_in_control(self) -> global___ComputeAutoscalerXAutoscalingPolicyXScaleInControl: ...
    @property
    def scaling_schedules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeAutoscalerXAutoscalingPolicyXScalingSchedules]: ...
    def __init__(
        self,
        *,
        cooldown_period: builtins.float = ...,
        max_replicas: builtins.float = ...,
        min_replicas: builtins.float = ...,
        mode: builtins.str = ...,
        cpu_utilization: global___ComputeAutoscalerXAutoscalingPolicyXCpuUtilization | None = ...,
        load_balancing_utilization: global___ComputeAutoscalerXAutoscalingPolicyXLoadBalancingUtilization | None = ...,
        metric: collections.abc.Iterable[global___ComputeAutoscalerXAutoscalingPolicyXMetric] | None = ...,
        scale_in_control: global___ComputeAutoscalerXAutoscalingPolicyXScaleInControl | None = ...,
        scaling_schedules: collections.abc.Iterable[global___ComputeAutoscalerXAutoscalingPolicyXScalingSchedules] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cpu_utilization", b"cpu_utilization", "load_balancing_utilization", b"load_balancing_utilization", "scale_in_control", b"scale_in_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cooldown_period", b"cooldown_period", "cpu_utilization", b"cpu_utilization", "load_balancing_utilization", b"load_balancing_utilization", "max_replicas", b"max_replicas", "metric", b"metric", "min_replicas", b"min_replicas", "mode", b"mode", "scale_in_control", b"scale_in_control", "scaling_schedules", b"scaling_schedules"]) -> None: ...

global___ComputeAutoscalerXAutoscalingPolicy = ComputeAutoscalerXAutoscalingPolicy

@typing_extensions.final
class ComputeAutoscalerXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeAutoscalerXTimeouts = ComputeAutoscalerXTimeouts

@typing_extensions.final
class ComputeAutoscaler(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    AUTOSCALING_POLICY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    target: builtins.str
    zone: builtins.str
    @property
    def autoscaling_policy(self) -> global___ComputeAutoscalerXAutoscalingPolicy: ...
    @property
    def timeouts(self) -> global___ComputeAutoscalerXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        target: builtins.str = ...,
        zone: builtins.str = ...,
        autoscaling_policy: global___ComputeAutoscalerXAutoscalingPolicy | None = ...,
        timeouts: global___ComputeAutoscalerXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscaling_policy", b"autoscaling_policy", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoscaling_policy", b"autoscaling_policy", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "target", b"target", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeAutoscaler = ComputeAutoscaler



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.authentication.v1alpha1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.authentication import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_authentication_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>kubernetes/kubernetes_io.k8s.api.authentication.v1alpha1.proto\x12+oak9.tython.k8s.api.authentication.v1alpha1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a\x38kubernetes/kubernetes_io.k8s.api.authentication.v1.proto\"\x92\x02\n\x11SelfSubjectReview\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12T\n\x06status\x18\x04 \x01(\x0b\x32\x44.oak9.tython.k8s.api.authentication.v1alpha1.SelfSubjectReviewStatus\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x96\x01\n\x17SelfSubjectReviewStatus\x12\x42\n\tuser_info\x18\x01 \x01(\x0b\x32/.oak9.tython.k8s.api.authentication.v1.UserInfo\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.authentication.v1alpha1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SELFSUBJECTREVIEW._serialized_start=257
  _SELFSUBJECTREVIEW._serialized_end=531
  _SELFSUBJECTREVIEWSTATUS._serialized_start=534
  _SELFSUBJECTREVIEWSTATUS._serialized_end=684
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_devices.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#azure/azure_microsoft_devices.proto\x12#oak9.tython.azure.microsoft_devices\x1a\x13shared/shared.proto\"\xa3\x02\n\x11Microsoft_Devices\x12>\n\x08iot_hubs\x18\x01 \x01(\x0b\x32,.oak9.tython.azure.microsoft_devices.IotHubs\x12W\n\x15iot_hubs_certificates\x18\x02 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_devices.IotHubsCertificates\x12u\n%iot_hubs_private_endpoint_connections\x18\x03 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_devices.IotHubsPrivateEndpointConnections\"n\n\nProperties\x12(\n enable_file_upload_notifications\x18\x01 \x01(\x08\x12\x17\n\x0fmin_tls_version\x18\x02 \x01(\t\x12\x1d\n\x15public_network_access\x18\x03 \x01(\t\"\xb1\x02\n!IotHubsPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12N\n\x10private_endpoint\x18\x03 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_devices.PrivateEndpoint\x12u\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_devices.PrivateLinkServiceConnectionState\"o\n&IotHubsEventHubEndpointsConsumerGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x86\x01\n\x13IotHubsCertificates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x63\x65rtificate\x18\x03 \x01(\t\x12\x13\n\x0bis_verified\x18\x04 \x01(\x08\"\xf8\x0c\n\x07IotHubs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x42\n\x08identity\x18\x03 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_devices.ArmIdentity\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x19\n\x11\x61llowed_fqdn_list\x18\x06 \x03(\t\x12k\n\x16\x61uthorization_policies\x18\x07 \x03(\x0b\x32K.oak9.tython.azure.microsoft_devices.SharedAccessSignatureAuthorizationRule\x12U\n\x0f\x63loud_to_device\x18\x08 \x01(\x0b\x32<.oak9.tython.azure.microsoft_devices.CloudToDeviceProperties\x12\x10\n\x08\x63omments\x18\t \x01(\t\x12\x1c\n\x14\x64isable_device_s_a_s\x18\n \x01(\x08\x12\x1a\n\x12\x64isable_local_auth\x18\x0b \x01(\x08\x12\x1c\n\x14\x64isable_module_s_a_s\x18\x0c \x01(\x08\x12\x1d\n\x15\x65nable_data_residency\x18\r \x01(\x08\x12`\n\x13\x65vent_hub_endpoints\x18\x0e \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_devices.IotHubs.EventHubEndpointsEntry\x12\x10\n\x08\x66\x65\x61tures\x18\x0f \x01(\t\x12J\n\x0fip_filter_rules\x18\x10 \x03(\x0b\x32\x31.oak9.tython.azure.microsoft_devices.IpFilterRule\x12\x61\n\x13messaging_endpoints\x18\x11 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_devices.IotHubs.MessagingEndpointsEntry\x12X\n\x11network_rule_sets\x18\x12 \x01(\x0b\x32=.oak9.tython.azure.microsoft_devices.NetworkRuleSetProperties\x12\x64\n\x1cprivate_endpoint_connections\x18\x13 \x03(\x0b\x32>.oak9.tython.azure.microsoft_devices.PrivateEndpointConnection\x12(\n restrict_outbound_network_access\x18\x14 \x01(\x08\x12G\n\x07routing\x18\x15 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_devices.RoutingProperties\x12]\n\x11storage_endpoints\x18\x16 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_devices.IotHubs.StorageEndpointsEntry\x12?\n\x03sku\x18\x17 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_devices.IotHubSkuInfo\x12\x44\n\x04tags\x18\x18 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_devices.IotHubs.TagsEntry\x12\x43\n\nproperties\x18\x19 \x01(\x0b\x32/.oak9.tython.azure.microsoft_devices.Properties\x1a\x38\n\x16\x45ventHubEndpointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x39\n\x17MessagingEndpointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15StorageEndpointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"/\n\rIotHubSkuInfo\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xc9\x02\n\x11RoutingProperties\x12H\n\tendpoints\x18\x01 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_devices.RoutingEndpoints\x12N\n\x0b\x65nrichments\x18\x02 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_devices.EnrichmentProperties\x12T\n\x0e\x66\x61llback_route\x18\x03 \x01(\x0b\x32<.oak9.tython.azure.microsoft_devices.FallbackRouteProperties\x12\x44\n\x06routes\x18\x04 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_devices.RouteProperties\"n\n\x0fRouteProperties\x12\x11\n\tcondition\x18\x01 \x01(\t\x12\x16\n\x0e\x65ndpoint_names\x18\x02 \x03(\t\x12\x12\n\nis_enabled\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06source\x18\x05 \x01(\t\"v\n\x17\x46\x61llbackRouteProperties\x12\x11\n\tcondition\x18\x01 \x01(\t\x12\x16\n\x0e\x65ndpoint_names\x18\x02 \x03(\t\x12\x12\n\nis_enabled\x18\x03 \x01(\x08\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06source\x18\x05 \x01(\t\"J\n\x14\x45nrichmentProperties\x12\x16\n\x0e\x65ndpoint_names\x18\x01 \x03(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xa0\x03\n\x10RoutingEndpoints\x12R\n\nevent_hubs\x18\x01 \x03(\x0b\x32>.oak9.tython.azure.microsoft_devices.RoutingEventHubProperties\x12i\n\x12service_bus_queues\x18\x02 \x03(\x0b\x32M.oak9.tython.azure.microsoft_devices.RoutingServiceBusQueueEndpointProperties\x12i\n\x12service_bus_topics\x18\x03 \x03(\x0b\x32M.oak9.tython.azure.microsoft_devices.RoutingServiceBusTopicEndpointProperties\x12\x62\n\x12storage_containers\x18\x04 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_devices.RoutingStorageContainerProperties\"\x8d\x03\n!RoutingStorageContainerProperties\x12\x1b\n\x13\x61uthentication_type\x18\x01 \x01(\t\x12\"\n\x1a\x62\x61tch_frequency_in_seconds\x18\x02 \x01(\x05\x12\x19\n\x11\x63onnection_string\x18\x03 \x01(\t\x12\x16\n\x0e\x63ontainer_name\x18\x04 \x01(\t\x12\x10\n\x08\x65ncoding\x18\x05 \x01(\t\x12\x14\n\x0c\x65ndpoint_uri\x18\x06 \x01(\t\x12\x18\n\x10\x66ile_name_format\x18\x07 \x01(\t\x12\n\n\x02id\x18\x08 \x01(\t\x12\x46\n\x08identity\x18\t \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_devices.ManagedIdentity\x12\x1f\n\x17max_chunk_size_in_bytes\x18\n \x01(\x05\x12\x0c\n\x04name\x18\x0b \x01(\t\x12\x16\n\x0eresource_group\x18\x0c \x01(\t\x12\x17\n\x0fsubscription_id\x18\r \x01(\t\"\xa0\x02\n(RoutingServiceBusTopicEndpointProperties\x12\x1b\n\x13\x61uthentication_type\x18\x01 \x01(\t\x12\x19\n\x11\x63onnection_string\x18\x02 \x01(\t\x12\x14\n\x0c\x65ndpoint_uri\x18\x03 \x01(\t\x12\x13\n\x0b\x65ntity_path\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x46\n\x08identity\x18\x06 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_devices.ManagedIdentity\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x16\n\x0eresource_group\x18\x08 \x01(\t\x12\x17\n\x0fsubscription_id\x18\t \x01(\t\"\xa0\x02\n(RoutingServiceBusQueueEndpointProperties\x12\x1b\n\x13\x61uthentication_type\x18\x01 \x01(\t\x12\x19\n\x11\x63onnection_string\x18\x02 \x01(\t\x12\x14\n\x0c\x65ndpoint_uri\x18\x03 \x01(\t\x12\x13\n\x0b\x65ntity_path\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x46\n\x08identity\x18\x06 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_devices.ManagedIdentity\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x16\n\x0eresource_group\x18\x08 \x01(\t\x12\x17\n\x0fsubscription_id\x18\t \x01(\t\"\x91\x02\n\x19RoutingEventHubProperties\x12\x1b\n\x13\x61uthentication_type\x18\x01 \x01(\t\x12\x19\n\x11\x63onnection_string\x18\x02 \x01(\t\x12\x14\n\x0c\x65ndpoint_uri\x18\x03 \x01(\t\x12\x13\n\x0b\x65ntity_path\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x46\n\x08identity\x18\x06 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_devices.ManagedIdentity\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x16\n\x0eresource_group\x18\x08 \x01(\t\x12\x17\n\x0fsubscription_id\x18\t \x01(\t\"1\n\x0fManagedIdentity\x12\x1e\n\x16user_assigned_identity\x18\x01 \x01(\t\"\xe2\x01\n\x19PrivateEndpointConnection\x12N\n\x10private_endpoint\x18\x01 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_devices.PrivateEndpoint\x12u\n%private_link_service_connection_state\x18\x02 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_devices.PrivateLinkServiceConnectionState\"b\n!PrivateLinkServiceConnectionState\x12\x18\n\x10\x61\x63tions_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1f\n\x0fPrivateEndpoint\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xad\x01\n\x18NetworkRuleSetProperties\x12,\n$apply_to_built_in_event_hub_endpoint\x18\x01 \x01(\x08\x12\x16\n\x0e\x64\x65\x66\x61ult_action\x18\x02 \x01(\t\x12K\n\x08ip_rules\x18\x03 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_devices.NetworkRuleSetIpRule\"L\n\x14NetworkRuleSetIpRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x66ilter_name\x18\x02 \x01(\t\x12\x0f\n\x07ip_mask\x18\x03 \x01(\t\"D\n\x0cIpFilterRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x66ilter_name\x18\x02 \x01(\t\x12\x0f\n\x07ip_mask\x18\x03 \x01(\t\"\xa0\x01\n\x17\x43loudToDeviceProperties\x12\x1e\n\x16\x64\x65\x66\x61ult_ttl_as_iso8601\x18\x01 \x01(\t\x12I\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x02 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_devices.FeedbackProperties\x12\x1a\n\x12max_delivery_count\x18\x03 \x01(\x05\"j\n\x12\x46\x65\x65\x64\x62\x61\x63kProperties\x12 \n\x18lock_duration_as_iso8601\x18\x01 \x01(\t\x12\x1a\n\x12max_delivery_count\x18\x02 \x01(\x05\x12\x16\n\x0ettl_as_iso8601\x18\x03 \x01(\t\"v\n&SharedAccessSignatureAuthorizationRule\x12\x10\n\x08key_name\x18\x01 \x01(\t\x12\x13\n\x0bprimary_key\x18\x02 \x01(\t\x12\x0e\n\x06rights\x18\x03 \x01(\t\x12\x15\n\rsecondary_key\x18\x04 \x01(\t\"\xca\x01\n\x0b\x41rmIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12n\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32L.oak9.tython.azure.microsoft_devices.ArmIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_devices_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IOTHUBS_EVENTHUBENDPOINTSENTRY._options = None
  _IOTHUBS_EVENTHUBENDPOINTSENTRY._serialized_options = b'8\001'
  _IOTHUBS_MESSAGINGENDPOINTSENTRY._options = None
  _IOTHUBS_MESSAGINGENDPOINTSENTRY._serialized_options = b'8\001'
  _IOTHUBS_STORAGEENDPOINTSENTRY._options = None
  _IOTHUBS_STORAGEENDPOINTSENTRY._serialized_options = b'8\001'
  _IOTHUBS_TAGSENTRY._options = None
  _IOTHUBS_TAGSENTRY._serialized_options = b'8\001'
  _ARMIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _ARMIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_DEVICES._serialized_start=98
  _MICROSOFT_DEVICES._serialized_end=389
  _PROPERTIES._serialized_start=391
  _PROPERTIES._serialized_end=501
  _IOTHUBSPRIVATEENDPOINTCONNECTIONS._serialized_start=504
  _IOTHUBSPRIVATEENDPOINTCONNECTIONS._serialized_end=809
  _IOTHUBSEVENTHUBENDPOINTSCONSUMERGROUPS._serialized_start=811
  _IOTHUBSEVENTHUBENDPOINTSCONSUMERGROUPS._serialized_end=922
  _IOTHUBSCERTIFICATES._serialized_start=925
  _IOTHUBSCERTIFICATES._serialized_end=1059
  _IOTHUBS._serialized_start=1062
  _IOTHUBS._serialized_end=2718
  _IOTHUBS_EVENTHUBENDPOINTSENTRY._serialized_start=2501
  _IOTHUBS_EVENTHUBENDPOINTSENTRY._serialized_end=2557
  _IOTHUBS_MESSAGINGENDPOINTSENTRY._serialized_start=2559
  _IOTHUBS_MESSAGINGENDPOINTSENTRY._serialized_end=2616
  _IOTHUBS_STORAGEENDPOINTSENTRY._serialized_start=2618
  _IOTHUBS_STORAGEENDPOINTSENTRY._serialized_end=2673
  _IOTHUBS_TAGSENTRY._serialized_start=2675
  _IOTHUBS_TAGSENTRY._serialized_end=2718
  _IOTHUBSKUINFO._serialized_start=2720
  _IOTHUBSKUINFO._serialized_end=2767
  _ROUTINGPROPERTIES._serialized_start=2770
  _ROUTINGPROPERTIES._serialized_end=3099
  _ROUTEPROPERTIES._serialized_start=3101
  _ROUTEPROPERTIES._serialized_end=3211
  _FALLBACKROUTEPROPERTIES._serialized_start=3213
  _FALLBACKROUTEPROPERTIES._serialized_end=3331
  _ENRICHMENTPROPERTIES._serialized_start=3333
  _ENRICHMENTPROPERTIES._serialized_end=3407
  _ROUTINGENDPOINTS._serialized_start=3410
  _ROUTINGENDPOINTS._serialized_end=3826
  _ROUTINGSTORAGECONTAINERPROPERTIES._serialized_start=3829
  _ROUTINGSTORAGECONTAINERPROPERTIES._serialized_end=4226
  _ROUTINGSERVICEBUSTOPICENDPOINTPROPERTIES._serialized_start=4229
  _ROUTINGSERVICEBUSTOPICENDPOINTPROPERTIES._serialized_end=4517
  _ROUTINGSERVICEBUSQUEUEENDPOINTPROPERTIES._serialized_start=4520
  _ROUTINGSERVICEBUSQUEUEENDPOINTPROPERTIES._serialized_end=4808
  _ROUTINGEVENTHUBPROPERTIES._serialized_start=4811
  _ROUTINGEVENTHUBPROPERTIES._serialized_end=5084
  _MANAGEDIDENTITY._serialized_start=5086
  _MANAGEDIDENTITY._serialized_end=5135
  _PRIVATEENDPOINTCONNECTION._serialized_start=5138
  _PRIVATEENDPOINTCONNECTION._serialized_end=5364
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=5366
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=5464
  _PRIVATEENDPOINT._serialized_start=5466
  _PRIVATEENDPOINT._serialized_end=5497
  _NETWORKRULESETPROPERTIES._serialized_start=5500
  _NETWORKRULESETPROPERTIES._serialized_end=5673
  _NETWORKRULESETIPRULE._serialized_start=5675
  _NETWORKRULESETIPRULE._serialized_end=5751
  _IPFILTERRULE._serialized_start=5753
  _IPFILTERRULE._serialized_end=5821
  _CLOUDTODEVICEPROPERTIES._serialized_start=5824
  _CLOUDTODEVICEPROPERTIES._serialized_end=5984
  _FEEDBACKPROPERTIES._serialized_start=5986
  _FEEDBACKPROPERTIES._serialized_end=6092
  _SHAREDACCESSSIGNATUREAUTHORIZATIONRULE._serialized_start=6094
  _SHAREDACCESSSIGNATUREAUTHORIZATIONRULE._serialized_end=6212
  _ARMIDENTITY._serialized_start=6215
  _ARMIDENTITY._serialized_end=6417
  _ARMIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=6356
  _ARMIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=6417
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class FlowDistinguisherMethod(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___FlowDistinguisherMethod = FlowDistinguisherMethod

@typing_extensions.final
class FlowSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___FlowSchemaSpec: ...
    @property
    def status(self) -> global___FlowSchemaStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___FlowSchemaSpec | None = ...,
        status: global___FlowSchemaStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___FlowSchema = FlowSchema

@typing_extensions.final
class FlowSchemaCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___FlowSchemaCondition = FlowSchemaCondition

@typing_extensions.final
class FlowSchemaList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FlowSchema]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___FlowSchema] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___FlowSchemaList = FlowSchemaList

@typing_extensions.final
class FlowSchemaSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISTINGUISHER_METHOD_FIELD_NUMBER: builtins.int
    MATCHING_PRECEDENCE_FIELD_NUMBER: builtins.int
    PRIORITY_LEVEL_CONFIGURATION_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def distinguisher_method(self) -> global___FlowDistinguisherMethod: ...
    matching_precedence: builtins.int
    @property
    def priority_level_configuration(self) -> global___PriorityLevelConfigurationReference: ...
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PolicyRulesWithSubjects]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        distinguisher_method: global___FlowDistinguisherMethod | None = ...,
        matching_precedence: builtins.int = ...,
        priority_level_configuration: global___PriorityLevelConfigurationReference | None = ...,
        rules: collections.abc.Iterable[global___PolicyRulesWithSubjects] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["distinguisher_method", b"distinguisher_method", "priority_level_configuration", b"priority_level_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["distinguisher_method", b"distinguisher_method", "matching_precedence", b"matching_precedence", "priority_level_configuration", b"priority_level_configuration", "resource_info", b"resource_info", "rules", b"rules"]) -> None: ...

global___FlowSchemaSpec = FlowSchemaSpec

@typing_extensions.final
class FlowSchemaStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDITIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FlowSchemaCondition]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        conditions: collections.abc.Iterable[global___FlowSchemaCondition] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conditions", b"conditions", "resource_info", b"resource_info"]) -> None: ...

global___FlowSchemaStatus = FlowSchemaStatus

@typing_extensions.final
class GroupSubject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___GroupSubject = GroupSubject

@typing_extensions.final
class LimitResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUEUING_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def queuing(self) -> global___QueuingConfiguration: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        queuing: global___QueuingConfiguration | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["queuing", b"queuing", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["queuing", b"queuing", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___LimitResponse = LimitResponse

@typing_extensions.final
class LimitedPriorityLevelConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ASSURED_CONCURRENCY_SHARES_FIELD_NUMBER: builtins.int
    BORROWING_LIMIT_PERCENT_FIELD_NUMBER: builtins.int
    LENDABLE_PERCENT_FIELD_NUMBER: builtins.int
    LIMIT_RESPONSE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    assured_concurrency_shares: builtins.int
    borrowing_limit_percent: builtins.int
    lendable_percent: builtins.int
    @property
    def limit_response(self) -> global___LimitResponse: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        assured_concurrency_shares: builtins.int = ...,
        borrowing_limit_percent: builtins.int = ...,
        lendable_percent: builtins.int = ...,
        limit_response: global___LimitResponse | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["limit_response", b"limit_response", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assured_concurrency_shares", b"assured_concurrency_shares", "borrowing_limit_percent", b"borrowing_limit_percent", "lendable_percent", b"lendable_percent", "limit_response", b"limit_response", "resource_info", b"resource_info"]) -> None: ...

global___LimitedPriorityLevelConfiguration = LimitedPriorityLevelConfiguration

@typing_extensions.final
class NonResourcePolicyRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NON_RESOURCE_U_R_LS_FIELD_NUMBER: builtins.int
    VERBS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def non_resource_u_r_ls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def verbs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        non_resource_u_r_ls: collections.abc.Iterable[builtins.str] | None = ...,
        verbs: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["non_resource_u_r_ls", b"non_resource_u_r_ls", "resource_info", b"resource_info", "verbs", b"verbs"]) -> None: ...

global___NonResourcePolicyRule = NonResourcePolicyRule

@typing_extensions.final
class PolicyRulesWithSubjects(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NON_RESOURCE_RULES_FIELD_NUMBER: builtins.int
    RESOURCE_RULES_FIELD_NUMBER: builtins.int
    SUBJECTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def non_resource_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NonResourcePolicyRule]: ...
    @property
    def resource_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourcePolicyRule]: ...
    @property
    def subjects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Subject]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        non_resource_rules: collections.abc.Iterable[global___NonResourcePolicyRule] | None = ...,
        resource_rules: collections.abc.Iterable[global___ResourcePolicyRule] | None = ...,
        subjects: collections.abc.Iterable[global___Subject] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["non_resource_rules", b"non_resource_rules", "resource_info", b"resource_info", "resource_rules", b"resource_rules", "subjects", b"subjects"]) -> None: ...

global___PolicyRulesWithSubjects = PolicyRulesWithSubjects

@typing_extensions.final
class PriorityLevelConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___PriorityLevelConfigurationSpec: ...
    @property
    def status(self) -> global___PriorityLevelConfigurationStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___PriorityLevelConfigurationSpec | None = ...,
        status: global___PriorityLevelConfigurationStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___PriorityLevelConfiguration = PriorityLevelConfiguration

@typing_extensions.final
class PriorityLevelConfigurationCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___PriorityLevelConfigurationCondition = PriorityLevelConfigurationCondition

@typing_extensions.final
class PriorityLevelConfigurationList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PriorityLevelConfiguration]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___PriorityLevelConfiguration] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___PriorityLevelConfigurationList = PriorityLevelConfigurationList

@typing_extensions.final
class PriorityLevelConfigurationReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___PriorityLevelConfigurationReference = PriorityLevelConfigurationReference

@typing_extensions.final
class PriorityLevelConfigurationSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIMITED_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def limited(self) -> global___LimitedPriorityLevelConfiguration: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        limited: global___LimitedPriorityLevelConfiguration | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["limited", b"limited", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["limited", b"limited", "resource_info", b"resource_info", "type", b"type"]) -> None: ...

global___PriorityLevelConfigurationSpec = PriorityLevelConfigurationSpec

@typing_extensions.final
class PriorityLevelConfigurationStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDITIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PriorityLevelConfigurationCondition]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        conditions: collections.abc.Iterable[global___PriorityLevelConfigurationCondition] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conditions", b"conditions", "resource_info", b"resource_info"]) -> None: ...

global___PriorityLevelConfigurationStatus = PriorityLevelConfigurationStatus

@typing_extensions.final
class QueuingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HAND_SIZE_FIELD_NUMBER: builtins.int
    QUEUE_LENGTH_LIMIT_FIELD_NUMBER: builtins.int
    QUEUES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    hand_size: builtins.int
    queue_length_limit: builtins.int
    queues: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        hand_size: builtins.int = ...,
        queue_length_limit: builtins.int = ...,
        queues: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hand_size", b"hand_size", "queue_length_limit", b"queue_length_limit", "queues", b"queues", "resource_info", b"resource_info"]) -> None: ...

global___QueuingConfiguration = QueuingConfiguration

@typing_extensions.final
class ResourcePolicyRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GROUPS_FIELD_NUMBER: builtins.int
    CLUSTER_SCOPE_FIELD_NUMBER: builtins.int
    NAMESPACES_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    VERBS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def api_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    cluster_scope: builtins.bool
    @property
    def namespaces(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resources(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def verbs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_groups: collections.abc.Iterable[builtins.str] | None = ...,
        cluster_scope: builtins.bool = ...,
        namespaces: collections.abc.Iterable[builtins.str] | None = ...,
        resources: collections.abc.Iterable[builtins.str] | None = ...,
        verbs: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_groups", b"api_groups", "cluster_scope", b"cluster_scope", "namespaces", b"namespaces", "resource_info", b"resource_info", "resources", b"resources", "verbs", b"verbs"]) -> None: ...

global___ResourcePolicyRule = ResourcePolicyRule

@typing_extensions.final
class ServiceAccountSubject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    namespace: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "namespace", b"namespace", "resource_info", b"resource_info"]) -> None: ...

global___ServiceAccountSubject = ServiceAccountSubject

@typing_extensions.final
class Subject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def group(self) -> global___GroupSubject: ...
    kind: builtins.str
    @property
    def service_account(self) -> global___ServiceAccountSubject: ...
    @property
    def user(self) -> global___UserSubject: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        group: global___GroupSubject | None = ...,
        kind: builtins.str = ...,
        service_account: global___ServiceAccountSubject | None = ...,
        user: global___UserSubject | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["group", b"group", "resource_info", b"resource_info", "service_account", b"service_account", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group", b"group", "kind", b"kind", "resource_info", b"resource_info", "service_account", b"service_account", "user", b"user"]) -> None: ...

global___Subject = Subject

@typing_extensions.final
class UserSubject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___UserSubject = UserSubject



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_sqs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_sqs.proto\x12\x13oak9.tython.aws.sqs\x1a\x13shared/shared.proto\"\xcf\x04\n\x05Queue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1b\x63ontent_based_deduplication\x18\x02 \x01(\x08\x12\x15\n\rdelay_seconds\x18\x03 \x01(\x05\x12\x12\n\nfifo_queue\x18\x04 \x01(\x08\x12)\n!kms_data_key_reuse_period_seconds\x18\x05 \x01(\x05\x12\x19\n\x11kms_master_key_id\x18\x06 \x01(\t\x12\x1c\n\x14maximum_message_size\x18\x07 \x01(\x05\x12 \n\x18message_retention_period\x18\x08 \x01(\x05\x12\x12\n\nqueue_name\x18\t \x01(\t\x12)\n!receive_message_wait_time_seconds\x18\n \x01(\x05\x12\x45\n\x0eredrive_policy\x18\x0b \x03(\x0b\x32-.oak9.tython.aws.sqs.Queue.RedrivePolicyEntry\x12\x32\n\x04tags\x18\x0c \x03(\x0b\x32$.oak9.tython.aws.sqs.Queue.TagsEntry\x12\x1a\n\x12visibility_timeout\x18\r \x01(\x05\x1a\x34\n\x12RedrivePolicyEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x03SQS\x12)\n\x05queue\x18\x01 \x01(\x0b\x32\x1a.oak9.tython.aws.sqs.Queue\x12\x36\n\x0cqueue_policy\x18\x02 \x01(\x0b\x32 .oak9.tython.aws.sqs.QueuePolicy\"o\n\x0bQueuePolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06queues\x18\x02 \x03(\t\x12\x17\n\x0fpolicy_document\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_sqs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _QUEUE_REDRIVEPOLICYENTRY._options = None
  _QUEUE_REDRIVEPOLICYENTRY._serialized_options = b'8\001'
  _QUEUE_TAGSENTRY._options = None
  _QUEUE_TAGSENTRY._serialized_options = b'8\001'
  _QUEUE._serialized_start=64
  _QUEUE._serialized_end=655
  _QUEUE_REDRIVEPOLICYENTRY._serialized_start=558
  _QUEUE_REDRIVEPOLICYENTRY._serialized_end=610
  _QUEUE_TAGSENTRY._serialized_start=612
  _QUEUE_TAGSENTRY._serialized_end=655
  _SQS._serialized_start=657
  _SQS._serialized_end=761
  _QUEUEPOLICY._serialized_start=763
  _QUEUEPOLICY._serialized_end=874
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_servicebus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&azure/azure_microsoft_servicebus.proto\x12&oak9.tython.azure.microsoft_servicebus\x1a\x13shared/shared.proto\"\x88\x02\n\x14Microsoft_ServiceBus\x12\x46\n\nnamespaces\x18\x01 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_servicebus.Namespaces\x12S\n\x11namespaces_queues\x18\x02 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_servicebus.NamespacesQueues\x12S\n\x11namespaces_topics\x18\x03 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_servicebus.NamespacesTopics\"\xde\x02\n\"NamespacesTopicsSubscriptionsRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12>\n\x06\x61\x63tion\x18\x03 \x01(\x0b\x32..oak9.tython.azure.microsoft_servicebus.Action\x12U\n\x12\x63orrelation_filter\x18\x04 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_servicebus.CorrelationFilter\x12\x13\n\x0b\x66ilter_type\x18\x05 \x01(\t\x12\x45\n\nsql_filter\x18\x06 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_servicebus.SqlFilter\"`\n\tSqlFilter\x12\x1b\n\x13\x63ompatibility_level\x18\x01 \x01(\x05\x12\x1e\n\x16requires_preprocessing\x18\x02 \x01(\x08\x12\x16\n\x0esql_expression\x18\x03 \x01(\t\"\xe5\x02\n\x11\x43orrelationFilter\x12\x14\n\x0c\x63ontent_type\x18\x01 \x01(\t\x12\x16\n\x0e\x63orrelation_id\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t\x12\x12\n\nmessage_id\x18\x04 \x01(\t\x12]\n\nproperties\x18\x05 \x03(\x0b\x32I.oak9.tython.azure.microsoft_servicebus.CorrelationFilter.PropertiesEntry\x12\x10\n\x08reply_to\x18\x06 \x01(\t\x12\x1b\n\x13reply_to_session_id\x18\x07 \x01(\t\x12\x1e\n\x16requires_preprocessing\x18\x08 \x01(\x08\x12\x12\n\nsession_id\x18\t \x01(\t\x12\n\n\x02to\x18\n \x01(\t\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x06\x41\x63tion\x12\x1b\n\x13\x63ompatibility_level\x18\x01 \x01(\x05\x12\x1e\n\x16requires_preprocessing\x18\x02 \x01(\x08\x12\x16\n\x0esql_expression\x18\x03 \x01(\t\"\xf8\x05\n\x1dNamespacesTopicsSubscriptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1b\n\x13\x61uto_delete_on_idle\x18\x03 \x01(\t\x12\x62\n\x18\x63lient_affine_properties\x18\x04 \x01(\x0b\x32@.oak9.tython.azure.microsoft_servicebus.SBClientAffineProperties\x12\x36\n.dead_lettering_on_filter_evaluation_exceptions\x18\x05 \x01(\x08\x12,\n$dead_lettering_on_message_expiration\x18\x06 \x01(\x08\x12$\n\x1c\x64\x65\x66\x61ult_message_time_to_live\x18\x07 \x01(\t\x12/\n\'duplicate_detection_history_time_window\x18\x08 \x01(\t\x12!\n\x19\x65nable_batched_operations\x18\t \x01(\x08\x12)\n!forward_dead_lettered_messages_to\x18\n \x01(\t\x12\x12\n\nforward_to\x18\x0b \x01(\t\x12\x18\n\x10is_client_affine\x18\x0c \x01(\x08\x12\x15\n\rlock_duration\x18\r \x01(\t\x12\x1a\n\x12max_delivery_count\x18\x0e \x01(\x05\x12\x18\n\x10requires_session\x18\x0f \x01(\x08\x12\x0e\n\x06status\x18\x10 \x01(\t\x12y\n%namespaces_topics_subscriptions_rules\x18\x11 \x03(\x0b\x32J.oak9.tython.azure.microsoft_servicebus.NamespacesTopicsSubscriptionsRules\"T\n\x18SBClientAffineProperties\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x12\n\nis_durable\x18\x02 \x01(\x08\x12\x11\n\tis_shared\x18\x03 \x01(\x08\"{\n\"NamespacesTopicsAuthorizationRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06rights\x18\x03 \x03(\t\"\xa6\x05\n\x10NamespacesTopics\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1b\n\x13\x61uto_delete_on_idle\x18\x03 \x01(\t\x12$\n\x1c\x64\x65\x66\x61ult_message_time_to_live\x18\x04 \x01(\t\x12/\n\'duplicate_detection_history_time_window\x18\x05 \x01(\t\x12!\n\x19\x65nable_batched_operations\x18\x06 \x01(\x08\x12\x16\n\x0e\x65nable_express\x18\x07 \x01(\x08\x12\x1b\n\x13\x65nable_partitioning\x18\x08 \x01(\x08\x12%\n\x1dmax_message_size_in_kilobytes\x18\t \x01(\x05\x12\x1d\n\x15max_size_in_megabytes\x18\n \x01(\x05\x12$\n\x1crequires_duplicate_detection\x18\x0b \x01(\x08\x12\x0e\n\x06status\x18\x0c \x01(\t\x12\x18\n\x10support_ordering\x18\r \x01(\x08\x12y\n%namespaces_topics_authorization_rules\x18\x0e \x03(\x0b\x32J.oak9.tython.azure.microsoft_servicebus.NamespacesTopicsAuthorizationRules\x12n\n\x1fnamespaces_topics_subscriptions\x18\x0f \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_servicebus.NamespacesTopicsSubscriptions\"{\n\"NamespacesQueuesAuthorizationRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06rights\x18\x03 \x03(\t\"\xd6\x05\n\x10NamespacesQueues\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1b\n\x13\x61uto_delete_on_idle\x18\x03 \x01(\t\x12,\n$dead_lettering_on_message_expiration\x18\x04 \x01(\x08\x12$\n\x1c\x64\x65\x66\x61ult_message_time_to_live\x18\x05 \x01(\t\x12/\n\'duplicate_detection_history_time_window\x18\x06 \x01(\t\x12!\n\x19\x65nable_batched_operations\x18\x07 \x01(\x08\x12\x16\n\x0e\x65nable_express\x18\x08 \x01(\x08\x12\x1b\n\x13\x65nable_partitioning\x18\t \x01(\x08\x12)\n!forward_dead_lettered_messages_to\x18\n \x01(\t\x12\x12\n\nforward_to\x18\x0b \x01(\t\x12\x15\n\rlock_duration\x18\x0c \x01(\t\x12\x1a\n\x12max_delivery_count\x18\r \x01(\x05\x12%\n\x1dmax_message_size_in_kilobytes\x18\x0e \x01(\x05\x12\x1d\n\x15max_size_in_megabytes\x18\x0f \x01(\x05\x12$\n\x1crequires_duplicate_detection\x18\x10 \x01(\x08\x12\x18\n\x10requires_session\x18\x11 \x01(\x08\x12\x0e\n\x06status\x18\x12 \x01(\t\x12y\n%namespaces_queues_authorization_rules\x18\x13 \x03(\x0b\x32J.oak9.tython.azure.microsoft_servicebus.NamespacesQueuesAuthorizationRules\"\xc4\x02\n$NamespacesPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Q\n\x10private_endpoint\x18\x03 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_servicebus.PrivateEndpoint\x12\x66\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_servicebus.ConnectionState\x12\x1a\n\x12provisioning_state\x18\x05 \x01(\t\"\xf2\x02\n\x19NamespacesNetworkRuleSets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x65\x66\x61ult_action\x18\x03 \x01(\t\x12J\n\x08ip_rules\x18\x04 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_servicebus.NWRuleSetIpRules\x12\x1d\n\x15public_network_access\x18\x05 \x01(\t\x12&\n\x1etrusted_service_access_enabled\x18\x06 \x01(\x08\x12\x63\n\x15virtual_network_rules\x18\x07 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_servicebus.NWRuleSetVirtualNetworkRules\"\x8c\x01\n\x1cNWRuleSetVirtualNetworkRules\x12,\n$ignore_missing_vnet_service_endpoint\x18\x01 \x01(\x08\x12>\n\x06subnet\x18\x02 \x01(\x0b\x32..oak9.tython.azure.microsoft_servicebus.Subnet\"\x14\n\x06Subnet\x12\n\n\x02id\x18\x01 \x01(\t\"3\n\x10NWRuleSetIpRules\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x0f\n\x07ip_mask\x18\x02 \x01(\t\"\xa1\x01\n!NamespacesMigrationConfigurations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1b\n\x13post_migration_name\x18\x03 \x01(\t\x12\x18\n\x10target_namespace\x18\x04 \x01(\t\"\x9d\x01\n!NamespacesDisasterRecoveryConfigs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x61lternate_name\x18\x03 \x01(\t\x12\x19\n\x11partner_namespace\x18\x04 \x01(\t\"u\n\x1cNamespacesAuthorizationRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06rights\x18\x03 \x03(\t\"\xe0\x08\n\nNamespaces\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x42\n\x08identity\x18\x02 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_servicebus.Identity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x16\n\x0e\x61lternate_name\x18\x05 \x01(\t\x12\x1a\n\x12\x64isable_local_auth\x18\x06 \x01(\x08\x12\x46\n\nencryption\x18\x07 \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_servicebus.Encryption\x12g\n\x1cprivate_endpoint_connections\x18\x08 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_servicebus.PrivateEndpointConnection\x12\x16\n\x0ezone_redundant\x18\t \x01(\x08\x12:\n\x03sku\x18\n \x01(\x0b\x32-.oak9.tython.azure.microsoft_servicebus.SBSku\x12J\n\x04tags\x18\x0b \x03(\x0b\x32<.oak9.tython.azure.microsoft_servicebus.Namespaces.TagsEntry\x12g\n\x1cnamespaces_network_rule_sets\x18\x0c \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_servicebus.NamespacesNetworkRuleSets\x12m\n\x1fnamespaces__authorization_rules\x18\r \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_servicebus.NamespacesAuthorizationRules\x12w\n$namespaces_disaster_recovery_configs\x18\x0e \x03(\x0b\x32I.oak9.tython.azure.microsoft_servicebus.NamespacesDisasterRecoveryConfigs\x12v\n#namespaces_migration_configurations\x18\x0f \x03(\x0b\x32I.oak9.tython.azure.microsoft_servicebus.NamespacesMigrationConfigurations\x12\x1b\n\x13minimum_tls_version\x18\x10 \x01(\t\x12\x1d\n\x15public_network_access\x18\x11 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x05SBSku\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04tier\x18\x03 \x01(\t\"\xf2\x01\n\x19PrivateEndpointConnection\x12Q\n\x10private_endpoint\x18\x01 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_servicebus.PrivateEndpoint\x12\x66\n%private_link_service_connection_state\x18\x02 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_servicebus.ConnectionState\x12\x1a\n\x12provisioning_state\x18\x03 \x01(\t\"6\n\x0f\x43onnectionState\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"\x1d\n\x0fPrivateEndpoint\x12\n\n\x02id\x18\x01 \x01(\t\"\xa5\x01\n\nEncryption\x12\x12\n\nkey_source\x18\x01 \x01(\t\x12X\n\x14key_vault_properties\x18\x02 \x03(\x0b\x32:.oak9.tython.azure.microsoft_servicebus.KeyVaultProperties\x12)\n!require_infrastructure_encryption\x18\x03 \x01(\x08\"\xac\x01\n\x12KeyVaultProperties\x12X\n\x08identity\x18\x01 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_servicebus.UserAssignedIdentityProperties\x12\x10\n\x08key_name\x18\x02 \x01(\t\x12\x15\n\rkey_vault_uri\x18\x03 \x01(\t\x12\x13\n\x0bkey_version\x18\x04 \x01(\t\"@\n\x1eUserAssignedIdentityProperties\x12\x1e\n\x16user_assigned_identity\x18\x01 \x01(\t\"\xc7\x01\n\x08Identity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12n\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32L.oak9.tython.azure.microsoft_servicebus.Identity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_servicebus_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CORRELATIONFILTER_PROPERTIESENTRY._options = None
  _CORRELATIONFILTER_PROPERTIESENTRY._serialized_options = b'8\001'
  _NAMESPACES_TAGSENTRY._options = None
  _NAMESPACES_TAGSENTRY._serialized_options = b'8\001'
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_SERVICEBUS._serialized_start=104
  _MICROSOFT_SERVICEBUS._serialized_end=368
  _NAMESPACESTOPICSSUBSCRIPTIONSRULES._serialized_start=371
  _NAMESPACESTOPICSSUBSCRIPTIONSRULES._serialized_end=721
  _SQLFILTER._serialized_start=723
  _SQLFILTER._serialized_end=819
  _CORRELATIONFILTER._serialized_start=822
  _CORRELATIONFILTER._serialized_end=1179
  _CORRELATIONFILTER_PROPERTIESENTRY._serialized_start=1130
  _CORRELATIONFILTER_PROPERTIESENTRY._serialized_end=1179
  _ACTION._serialized_start=1181
  _ACTION._serialized_end=1274
  _NAMESPACESTOPICSSUBSCRIPTIONS._serialized_start=1277
  _NAMESPACESTOPICSSUBSCRIPTIONS._serialized_end=2037
  _SBCLIENTAFFINEPROPERTIES._serialized_start=2039
  _SBCLIENTAFFINEPROPERTIES._serialized_end=2123
  _NAMESPACESTOPICSAUTHORIZATIONRULES._serialized_start=2125
  _NAMESPACESTOPICSAUTHORIZATIONRULES._serialized_end=2248
  _NAMESPACESTOPICS._serialized_start=2251
  _NAMESPACESTOPICS._serialized_end=2929
  _NAMESPACESQUEUESAUTHORIZATIONRULES._serialized_start=2931
  _NAMESPACESQUEUESAUTHORIZATIONRULES._serialized_end=3054
  _NAMESPACESQUEUES._serialized_start=3057
  _NAMESPACESQUEUES._serialized_end=3783
  _NAMESPACESPRIVATEENDPOINTCONNECTIONS._serialized_start=3786
  _NAMESPACESPRIVATEENDPOINTCONNECTIONS._serialized_end=4110
  _NAMESPACESNETWORKRULESETS._serialized_start=4113
  _NAMESPACESNETWORKRULESETS._serialized_end=4483
  _NWRULESETVIRTUALNETWORKRULES._serialized_start=4486
  _NWRULESETVIRTUALNETWORKRULES._serialized_end=4626
  _SUBNET._serialized_start=4628
  _SUBNET._serialized_end=4648
  _NWRULESETIPRULES._serialized_start=4650
  _NWRULESETIPRULES._serialized_end=4701
  _NAMESPACESMIGRATIONCONFIGURATIONS._serialized_start=4704
  _NAMESPACESMIGRATIONCONFIGURATIONS._serialized_end=4865
  _NAMESPACESDISASTERRECOVERYCONFIGS._serialized_start=4868
  _NAMESPACESDISASTERRECOVERYCONFIGS._serialized_end=5025
  _NAMESPACESAUTHORIZATIONRULES._serialized_start=5027
  _NAMESPACESAUTHORIZATIONRULES._serialized_end=5144
  _NAMESPACES._serialized_start=5147
  _NAMESPACES._serialized_end=6267
  _NAMESPACES_TAGSENTRY._serialized_start=6224
  _NAMESPACES_TAGSENTRY._serialized_end=6267
  _SBSKU._serialized_start=6269
  _SBSKU._serialized_end=6322
  _PRIVATEENDPOINTCONNECTION._serialized_start=6325
  _PRIVATEENDPOINTCONNECTION._serialized_end=6567
  _CONNECTIONSTATE._serialized_start=6569
  _CONNECTIONSTATE._serialized_end=6623
  _PRIVATEENDPOINT._serialized_start=6625
  _PRIVATEENDPOINT._serialized_end=6654
  _ENCRYPTION._serialized_start=6657
  _ENCRYPTION._serialized_end=6822
  _KEYVAULTPROPERTIES._serialized_start=6825
  _KEYVAULTPROPERTIES._serialized_end=6997
  _USERASSIGNEDIDENTITYPROPERTIES._serialized_start=6999
  _USERASSIGNEDIDENTITYPROPERTIES._serialized_end=7063
  _IDENTITY._serialized_start=7066
  _IDENTITY._serialized_end=7265
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=7204
  _IDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=7265
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_docdb.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61ws/aws_docdb.proto\x12\x15oak9.tython.aws.docdb\x1a\x13shared/shared.proto\"\xa3\x05\n\tDBCluster\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11storage_encrypted\x18\x02 \x01(\x08\x12\x16\n\x0e\x65ngine_version\x18\x03 \x01(\t\x12\x12\n\nkms_key_id\x18\x04 \x01(\t\x12\x1a\n\x12\x61vailability_zones\x18\x05 \x03(\t\x12\x1b\n\x13snapshot_identifier\x18\x06 \x01(\t\x12\x0c\n\x04port\x18\x07 \x01(\x05\x12\x1d\n\x15\x64\x62_cluster_identifier\x18\x08 \x01(\t\x12$\n\x1cpreferred_maintenance_window\x18\t \x01(\t\x12\x1c\n\x14\x64\x62_subnet_group_name\x18\n \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0b \x01(\x08\x12\x1f\n\x17preferred_backup_window\x18\x0c \x01(\t\x12\x1c\n\x14master_user_password\x18\r \x01(\t\x12\x1e\n\x16vpc_security_group_ids\x18\x0e \x03(\t\x12\x17\n\x0fmaster_username\x18\x0f \x01(\t\x12\'\n\x1f\x64\x62_cluster_parameter_group_name\x18\x10 \x01(\t\x12\x1f\n\x17\x62\x61\x63kup_retention_period\x18\x11 \x01(\x05\x12\x38\n\x04tags\x18\x12 \x03(\x0b\x32*.oak9.tython.aws.docdb.DBCluster.TagsEntry\x12&\n\x1e\x65nable_cloudwatch_logs_exports\x18\x13 \x03(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x02\n\x05\x44ocDB\x12\x34\n\ndb_cluster\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.docdb.DBCluster\x12R\n\x1a\x64\x62_cluster_parameter_group\x18\x02 \x03(\x0b\x32..oak9.tython.aws.docdb.DBClusterParameterGroup\x12\x36\n\x0b\x64\x62_instance\x18\x03 \x03(\x0b\x32!.oak9.tython.aws.docdb.DBInstance\x12=\n\x0f\x64\x62_subnet_group\x18\x04 \x03(\x0b\x32$.oak9.tython.aws.docdb.DBSubnetGroup\"\x81\x03\n\x17\x44\x42\x43lusterParameterGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12R\n\nparameters\x18\x03 \x03(\x0b\x32>.oak9.tython.aws.docdb.DBClusterParameterGroup.ParametersEntry\x12\x0e\n\x06\x66\x61mily\x18\x04 \x01(\t\x12\x46\n\x04tags\x18\x05 \x03(\x0b\x32\x38.oak9.tython.aws.docdb.DBClusterParameterGroup.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xec\x02\n\nDBInstance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x64\x62_instance_class\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x62_cluster_identifier\x18\x03 \x01(\t\x12\x19\n\x11\x61vailability_zone\x18\x04 \x01(\t\x12$\n\x1cpreferred_maintenance_window\x18\x05 \x01(\t\x12\"\n\x1a\x61uto_minor_version_upgrade\x18\x06 \x01(\x08\x12\x1e\n\x16\x64\x62_instance_identifier\x18\x07 \x01(\t\x12\x39\n\x04tags\x18\x08 \x03(\x0b\x32+.oak9.tython.aws.docdb.DBInstance.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8a\x02\n\rDBSubnetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14\x64\x62_subnet_group_name\x18\x02 \x01(\t\x12#\n\x1b\x64\x62_subnet_group_description\x18\x03 \x01(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\t\x12<\n\x04tags\x18\x05 \x03(\x0b\x32..oak9.tython.aws.docdb.DBSubnetGroup.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_docdb_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DBCLUSTER_TAGSENTRY._options = None
  _DBCLUSTER_TAGSENTRY._serialized_options = b'8\001'
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._options = None
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._serialized_options = b'8\001'
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._options = None
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBINSTANCE_TAGSENTRY._options = None
  _DBINSTANCE_TAGSENTRY._serialized_options = b'8\001'
  _DBSUBNETGROUP_TAGSENTRY._options = None
  _DBSUBNETGROUP_TAGSENTRY._serialized_options = b'8\001'
  _DBCLUSTER._serialized_start=68
  _DBCLUSTER._serialized_end=743
  _DBCLUSTER_TAGSENTRY._serialized_start=700
  _DBCLUSTER_TAGSENTRY._serialized_end=743
  _DOCDB._serialized_start=746
  _DOCDB._serialized_end=1010
  _DBCLUSTERPARAMETERGROUP._serialized_start=1013
  _DBCLUSTERPARAMETERGROUP._serialized_end=1398
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._serialized_start=1304
  _DBCLUSTERPARAMETERGROUP_PARAMETERSENTRY._serialized_end=1353
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._serialized_start=700
  _DBCLUSTERPARAMETERGROUP_TAGSENTRY._serialized_end=743
  _DBINSTANCE._serialized_start=1401
  _DBINSTANCE._serialized_end=1765
  _DBINSTANCE_TAGSENTRY._serialized_start=700
  _DBINSTANCE_TAGSENTRY._serialized_end=743
  _DBSUBNETGROUP._serialized_start=1768
  _DBSUBNETGROUP._serialized_end=2034
  _DBSUBNETGROUP_TAGSENTRY._serialized_start=700
  _DBSUBNETGROUP_TAGSENTRY._serialized_end=743
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeForwardingRuleXServiceDirectoryRegistrations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    namespace: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        namespace: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace", b"namespace", "service", b"service"]) -> None: ...

global___ComputeForwardingRuleXServiceDirectoryRegistrations = ComputeForwardingRuleXServiceDirectoryRegistrations

@typing_extensions.final
class ComputeForwardingRuleXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeForwardingRuleXTimeouts = ComputeForwardingRuleXTimeouts

@typing_extensions.final
class ComputeForwardingRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ALL_PORTS_FIELD_NUMBER: builtins.int
    ALLOW_GLOBAL_ACCESS_FIELD_NUMBER: builtins.int
    BACKEND_SERVICE_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    IP_PROTOCOL_FIELD_NUMBER: builtins.int
    IS_MIRRORING_COLLECTOR_FIELD_NUMBER: builtins.int
    LABEL_FINGERPRINT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOAD_BALANCING_SCHEME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NETWORK_TIER_FIELD_NUMBER: builtins.int
    PORT_RANGE_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PSC_CONNECTION_ID_FIELD_NUMBER: builtins.int
    PSC_CONNECTION_STATUS_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SERVICE_LABEL_FIELD_NUMBER: builtins.int
    SERVICE_NAME_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    SERVICE_DIRECTORY_REGISTRATIONS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    all_ports: builtins.bool
    allow_global_access: builtins.bool
    backend_service: builtins.str
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    ip_address: builtins.str
    ip_protocol: builtins.str
    is_mirroring_collector: builtins.bool
    label_fingerprint: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    load_balancing_scheme: builtins.str
    name: builtins.str
    network: builtins.str
    network_tier: builtins.str
    port_range: builtins.str
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    psc_connection_id: builtins.str
    psc_connection_status: builtins.str
    region: builtins.str
    self_link: builtins.str
    service_label: builtins.str
    service_name: builtins.str
    subnetwork: builtins.str
    target: builtins.str
    @property
    def service_directory_registrations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeForwardingRuleXServiceDirectoryRegistrations]: ...
    @property
    def timeouts(self) -> global___ComputeForwardingRuleXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        all_ports: builtins.bool = ...,
        allow_global_access: builtins.bool = ...,
        backend_service: builtins.str = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        ip_address: builtins.str = ...,
        ip_protocol: builtins.str = ...,
        is_mirroring_collector: builtins.bool = ...,
        label_fingerprint: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        load_balancing_scheme: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        network_tier: builtins.str = ...,
        port_range: builtins.str = ...,
        ports: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        psc_connection_id: builtins.str = ...,
        psc_connection_status: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        service_label: builtins.str = ...,
        service_name: builtins.str = ...,
        subnetwork: builtins.str = ...,
        target: builtins.str = ...,
        service_directory_registrations: collections.abc.Iterable[global___ComputeForwardingRuleXServiceDirectoryRegistrations] | None = ...,
        timeouts: global___ComputeForwardingRuleXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["all_ports", b"all_ports", "allow_global_access", b"allow_global_access", "backend_service", b"backend_service", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "ip_address", b"ip_address", "ip_protocol", b"ip_protocol", "is_mirroring_collector", b"is_mirroring_collector", "label_fingerprint", b"label_fingerprint", "labels", b"labels", "load_balancing_scheme", b"load_balancing_scheme", "name", b"name", "network", b"network", "network_tier", b"network_tier", "port_range", b"port_range", "ports", b"ports", "project", b"project", "psc_connection_id", b"psc_connection_id", "psc_connection_status", b"psc_connection_status", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "service_directory_registrations", b"service_directory_registrations", "service_label", b"service_label", "service_name", b"service_name", "subnetwork", b"subnetwork", "target", b"target", "timeouts", b"timeouts"]) -> None: ...

global___ComputeForwardingRule = ComputeForwardingRule



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DBClusterDBClusterRole(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FEATURE_NAME_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    feature_name: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        feature_name: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_name", b"feature_name", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___DBClusterDBClusterRole = DBClusterDBClusterRole

@typing_extensions.final
class RDS(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DB_CLUSTER_DB_CLUSTER_ROLE_FIELD_NUMBER: builtins.int
    DB_CLUSTER_SCALING_CONFIGURATION_FIELD_NUMBER: builtins.int
    DB_INSTANCE_DB_INSTANCE_ROLE_FIELD_NUMBER: builtins.int
    DB_INSTANCE_PROCESSOR_FEATURE_FIELD_NUMBER: builtins.int
    DB_PROXY_AUTH_FORMAT_FIELD_NUMBER: builtins.int
    DB_PROXY_TAG_FORMAT_FIELD_NUMBER: builtins.int
    DB_PROXY_TARGET_GROUP_CONNECTION_POOL_CONFIGURATION_INFO_FORMAT_FIELD_NUMBER: builtins.int
    DB_SECURITY_GROUP_INGRESS_FIELD_NUMBER: builtins.int
    OPTION_GROUP_OPTION_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def db_cluster_db_cluster_role(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBClusterDBClusterRole]: ...
    @property
    def db_cluster_scaling_configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBClusterScalingConfiguration]: ...
    @property
    def db_instance_db_instance_role(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBInstanceDBInstanceRole]: ...
    @property
    def db_instance_processor_feature(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBInstanceProcessorFeature]: ...
    @property
    def db_proxy_auth_format(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBProxyAuthFormat]: ...
    @property
    def db_proxy_tag_format(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBProxyTagFormat]: ...
    @property
    def db_proxy_target_group_connection_pool_configuration_info_format(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBProxyTargetGroupConnectionPoolConfigurationInfoFormat]: ...
    @property
    def db_security_group_ingress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DBSecurityGroupIngress]: ...
    @property
    def option_group_option_configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OptionGroupOptionConfiguration]: ...
    def __init__(
        self,
        *,
        db_cluster_db_cluster_role: collections.abc.Iterable[global___DBClusterDBClusterRole] | None = ...,
        db_cluster_scaling_configuration: collections.abc.Iterable[global___DBClusterScalingConfiguration] | None = ...,
        db_instance_db_instance_role: collections.abc.Iterable[global___DBInstanceDBInstanceRole] | None = ...,
        db_instance_processor_feature: collections.abc.Iterable[global___DBInstanceProcessorFeature] | None = ...,
        db_proxy_auth_format: collections.abc.Iterable[global___DBProxyAuthFormat] | None = ...,
        db_proxy_tag_format: collections.abc.Iterable[global___DBProxyTagFormat] | None = ...,
        db_proxy_target_group_connection_pool_configuration_info_format: collections.abc.Iterable[global___DBProxyTargetGroupConnectionPoolConfigurationInfoFormat] | None = ...,
        db_security_group_ingress: collections.abc.Iterable[global___DBSecurityGroupIngress] | None = ...,
        option_group_option_configuration: collections.abc.Iterable[global___OptionGroupOptionConfiguration] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["db_cluster_db_cluster_role", b"db_cluster_db_cluster_role", "db_cluster_scaling_configuration", b"db_cluster_scaling_configuration", "db_instance_db_instance_role", b"db_instance_db_instance_role", "db_instance_processor_feature", b"db_instance_processor_feature", "db_proxy_auth_format", b"db_proxy_auth_format", "db_proxy_tag_format", b"db_proxy_tag_format", "db_proxy_target_group_connection_pool_configuration_info_format", b"db_proxy_target_group_connection_pool_configuration_info_format", "db_security_group_ingress", b"db_security_group_ingress", "option_group_option_configuration", b"option_group_option_configuration"]) -> None: ...

global___RDS = RDS

@typing_extensions.final
class DBClusterScalingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTO_PAUSE_FIELD_NUMBER: builtins.int
    MAX_CAPACITY_FIELD_NUMBER: builtins.int
    MIN_CAPACITY_FIELD_NUMBER: builtins.int
    SECONDS_UNTIL_AUTO_PAUSE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    auto_pause: builtins.bool
    max_capacity: builtins.int
    min_capacity: builtins.int
    seconds_until_auto_pause: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        auto_pause: builtins.bool = ...,
        max_capacity: builtins.int = ...,
        min_capacity: builtins.int = ...,
        seconds_until_auto_pause: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_pause", b"auto_pause", "max_capacity", b"max_capacity", "min_capacity", b"min_capacity", "resource_info", b"resource_info", "seconds_until_auto_pause", b"seconds_until_auto_pause"]) -> None: ...

global___DBClusterScalingConfiguration = DBClusterScalingConfiguration

@typing_extensions.final
class DBInstanceDBInstanceRole(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FEATURE_NAME_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    feature_name: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        feature_name: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_name", b"feature_name", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___DBInstanceDBInstanceRole = DBInstanceDBInstanceRole

@typing_extensions.final
class DBInstanceProcessorFeature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DBInstanceProcessorFeature = DBInstanceProcessorFeature

@typing_extensions.final
class DBProxyAuthFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AUTH_SCHEME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    IAM_AUTH_FIELD_NUMBER: builtins.int
    SECRET_ARN_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    auth_scheme: builtins.str
    description: builtins.str
    iam_auth: builtins.str
    secret_arn: builtins.str
    user_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        auth_scheme: builtins.str = ...,
        description: builtins.str = ...,
        iam_auth: builtins.str = ...,
        secret_arn: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_scheme", b"auth_scheme", "description", b"description", "iam_auth", b"iam_auth", "resource_info", b"resource_info", "secret_arn", b"secret_arn", "user_name", b"user_name"]) -> None: ...

global___DBProxyAuthFormat = DBProxyAuthFormat

@typing_extensions.final
class DBProxyTagFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DBProxyTagFormat = DBProxyTagFormat

@typing_extensions.final
class DBProxyTargetGroupConnectionPoolConfigurationInfoFormat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAX_CONNECTIONS_PERCENT_FIELD_NUMBER: builtins.int
    MAX_IDLE_CONNECTIONS_PERCENT_FIELD_NUMBER: builtins.int
    CONNECTION_BORROW_TIMEOUT_FIELD_NUMBER: builtins.int
    SESSION_PINNING_FILTERS_FIELD_NUMBER: builtins.int
    INIT_QUERY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    max_connections_percent: builtins.int
    max_idle_connections_percent: builtins.int
    connection_borrow_timeout: builtins.int
    @property
    def session_pinning_filters(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    init_query: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        max_connections_percent: builtins.int = ...,
        max_idle_connections_percent: builtins.int = ...,
        connection_borrow_timeout: builtins.int = ...,
        session_pinning_filters: collections.abc.Iterable[builtins.str] | None = ...,
        init_query: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_borrow_timeout", b"connection_borrow_timeout", "init_query", b"init_query", "max_connections_percent", b"max_connections_percent", "max_idle_connections_percent", b"max_idle_connections_percent", "resource_info", b"resource_info", "session_pinning_filters", b"session_pinning_filters"]) -> None: ...

global___DBProxyTargetGroupConnectionPoolConfigurationInfoFormat = DBProxyTargetGroupConnectionPoolConfigurationInfoFormat

@typing_extensions.final
class DBSecurityGroupIngress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CIDR_IP_FIELD_NUMBER: builtins.int
    E_C2_SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    E_C2_SECURITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    E_C2_SECURITY_GROUP_OWNER_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cidr_ip: builtins.str
    e_c2_security_group_id: builtins.str
    e_c2_security_group_name: builtins.str
    e_c2_security_group_owner_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cidr_ip: builtins.str = ...,
        e_c2_security_group_id: builtins.str = ...,
        e_c2_security_group_name: builtins.str = ...,
        e_c2_security_group_owner_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cidr_ip", b"cidr_ip", "e_c2_security_group_id", b"e_c2_security_group_id", "e_c2_security_group_name", b"e_c2_security_group_name", "e_c2_security_group_owner_id", b"e_c2_security_group_owner_id", "resource_info", b"resource_info"]) -> None: ...

global___DBSecurityGroupIngress = DBSecurityGroupIngress

@typing_extensions.final
class OptionGroupOptionSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___OptionGroupOptionSetting = OptionGroupOptionSetting

@typing_extensions.final
class OptionGroupOptionConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DB_SECURITY_GROUP_MEMBERSHIPS_FIELD_NUMBER: builtins.int
    OPTION_NAME_FIELD_NUMBER: builtins.int
    OPTION_SETTINGS_FIELD_NUMBER: builtins.int
    OPTION_VERSION_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    VPC_SECURITY_GROUP_MEMBERSHIPS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def db_security_group_memberships(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    option_name: builtins.str
    @property
    def option_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OptionGroupOptionSetting]: ...
    option_version: builtins.str
    port: builtins.int
    @property
    def vpc_security_group_memberships(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        db_security_group_memberships: collections.abc.Iterable[builtins.str] | None = ...,
        option_name: builtins.str = ...,
        option_settings: collections.abc.Iterable[global___OptionGroupOptionSetting] | None = ...,
        option_version: builtins.str = ...,
        port: builtins.int = ...,
        vpc_security_group_memberships: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["db_security_group_memberships", b"db_security_group_memberships", "option_name", b"option_name", "option_settings", b"option_settings", "option_version", b"option_version", "port", b"port", "resource_info", b"resource_info", "vpc_security_group_memberships", b"vpc_security_group_memberships"]) -> None: ...

global___OptionGroupOptionConfiguration = OptionGroupOptionConfiguration
